@@ -1,49 +1,41 @@
 package Pfacter::processorcount;
 
+#
+
 sub pfact {
     my $self  = shift;
     my ( $p ) = shift->{'pfact'};
 
+    my ( $r );
+
     for ( $p->{'kernel'} ) {
         /AIX/ && do {
             if ( -e '/usr/sbin/lsdev' ) {
-                my ( $c ) = 0;
-
                 open( F, '/usr/sbin/lsdev -Cc processor |' );
                 my ( @F ) = <F>;
                 close( F );
 
-                foreach ( @F ) { $c++ if /Available/; }
-
-                return $c;
+                foreach ( @F ) { $r++ if /Available/; }
             }
         };
 
         /FreeBSD/ && do {
             if ( -e '/sbin/dmesg' ) {
-                my ( $c ) = 0;
-
                 open( F, '/sbin/dmesg |' );
                 my ( @F ) = <F>;
                 close( F );
 
-                foreach ( @F ) { $c++ if /^CPU/; }
-
-                return $c;
+                foreach ( @F ) { $r++ if /^CPU/; }
             }
         };
 
         /Linux/ && do {
             if ( -e '/proc/cpuinfo' ) {
-                my ( $c ) = 0;
-
                 open( F, '/proc/cpuinfo' );
                 my ( @F ) = <F>;
                 close( F );
 
-                foreach ( @F ) { $c++ if /processor\s+:\s+(\d+)/; }
-
-                return $c;
+                foreach ( @F ) { $r++ if /processor\s+:\s+(\d+)/; }
             }
         };
 
@@ -53,11 +45,12 @@ sub pfact {
                 my ( @F ) = <F>;
                 close( F );
 
-                return scalar @F;
+                $r = scalar @F;
             }
         };
 
-        return qq((kernel not supported));
+        if ( $r ) { return( $r ); }
+        else      { return( 0 ); }
     }
 }
 
